@@ -11,6 +11,9 @@ cat("* be applied to obtain estimates for the adjusted differences between
 cat("* treatment means and the standard error associated with these differences.*\n")
 cat("* Log-transformed BA measures will also be analyzed.                       *\n")
 cat("****************************************************************************\n")
+TotalData<-data.frame (subj=as.factor(TotalData$subj), drug=as.factor(TotalData$drug),seq=as.factor(TotalData$seq),
+                   prd=as.factor(TotalData$prd),Cmax=TotalData$Cmax, AUC0t=TotalData$AUC0t, AUC0INF=TotalData$AUC0INF, 
+                   LnCmax=log(TotalData$Cmax),LnAUC0t=log(TotalData$AUC0t),LnAUC0INF=log(TotalData$AUC0INF)) 
 
 Fdata<-split(TotalData, list(TotalData$drug))
 RefData<-Fdata[[1]]
@@ -22,14 +25,16 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: Cmax                                                  \n")
 cat("\n")
-Cmax<- lm(Cmax ~ seq + subj + prd + drug , data=TotalData)
-summary(Cmax)
-show(anova(Cmax))
+cat("Type I SS\n")
+Cmax<- lm(Cmax ~ seq + subj:seq + prd + drug , data=TotalData)
+show(anova(Cmax)) 
+cat("\n")
+cat("Type III SS\n")
+show(drop1(Cmax, test="F"))
 cat("\n")
 cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-cat("\n")
-Cmax1<- lm(Cmax ~ seq , data=TotalData)
-show(anova(Cmax1))
+print(summary(aov(Cmax ~ prd*drug + Error(subj) , data=TotalData)))
+cat("\n")  
 cat("****************************************************************************\n")
 
 cat("\n")
@@ -39,14 +44,16 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: AUC0t                                                \n")
 cat("\n")
-AUC0t<- lm(AUC0t ~ seq + subj+ prd + drug , data=TotalData)
-summary(AUC0t)
+cat("Type I SS\n")
+AUC0t<- lm(AUC0t ~ seq + subj:seq+ prd + drug , data=TotalData)
 show(anova(AUC0t))
 cat("\n")
-cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+cat("Type III SS\n")
+show(drop1(AUC0t, test="F"))
 cat("\n")
-AUC0t1<- lm(AUC0t ~ seq , data=TotalData)
-show(anova(AUC0t1))
+cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+print(summary(aov(AUC0t ~ prd*drug + Error(subj) , data=TotalData)))
+cat("\n")  
 cat("****************************************************************************\n")
 
 cat("\n")
@@ -56,14 +63,16 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: AUC0inf                                               \n")
 cat("\n")
-AUC0INF<- lm(AUC0INF ~ seq + subj+ prd + drug , data=TotalData)
-summary(AUC0INF)
+cat("Type I SS\n")
+AUC0INF<- lm(AUC0INF ~ seq + subj:seq + prd + drug , data=TotalData)
 show(anova(AUC0INF))
 cat("\n")
-cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+cat("Type III SS\n")
+show(drop1(AUC0INF, test="F")) 
 cat("\n")
-AUC0INF1<- lm(AUC0INF ~ seq , data=TotalData)
-show(anova(AUC0INF1))
+cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+print(summary(aov(AUC0INF ~ prd*drug + Error(subj) , data=TotalData)))
+cat("\n") 
 cat("****************************************************************************\n")
 
 cat("\n")
@@ -73,14 +82,15 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: LnCmax                                               \n")
 cat("\n")
-LnCmax<- lm(LnCmax ~ seq + subj + prd + drug , data=TotalData)
-summary(LnCmax)
+cat("Type I SS\n")
+LnCmax<- lm(LnCmax ~ seq + subj:seq + prd + drug , data=TotalData)
 show(anova(LnCmax))
 cat("\n")
-cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+cat("Type III SS\n")
+show(drop1(LnCmax, test="F"))
 cat("\n")
-LnCmax1<- lm(LnCmax ~ seq , data=TotalData)
-show(anova(LnCmax1))
+cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+print(summary(aov(LnCmax ~ prd*drug + Error(subj) , data=TotalData)))  
 cat("\n")
 cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnCmax)[5,3]),"%\n")
 cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnCmax)[2,3]-anova(LnCmax)[5,3])/2),"%\n")
@@ -93,14 +103,15 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: LnAUC0t                                               \n")
 cat("\n")
-LnAUC0t<- lm(LnAUC0t ~ seq + subj + prd + drug , data=TotalData)
-summary(LnAUC0t)
+cat("Type I SS\n")
+LnAUC0t<- lm(LnAUC0t ~ seq + subj:seq + prd + drug , data=TotalData)
 show(anova(LnAUC0t))
 cat("\n")
-cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+cat("Type III SS\n")
+show(drop1(LnAUC0t, test="F")) 
 cat("\n")
-LnAUC0t1<- lm(LnAUC0t ~ seq , data=TotalData)
-show(anova(LnAUC0t1))
+cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+print(summary(aov(LnAUC0t ~ prd*drug + Error(subj) , data=TotalData))) 
 cat("\n")
 cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnAUC0t)[5,3]),"%\n")
 cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnAUC0t)[2,3]-anova(LnAUC0t)[5,3])/2),"%\n")
@@ -113,14 +124,15 @@ cat("*                           ANOVA (lm) Procedure
 cat("*--------------------------------------------------------------------------*\n")
 cat("  Dependent Variable: LnAUC0inf                                             \n")
 cat("\n")
-LnAUC0INF<- lm(LnAUC0INF ~ seq + subj + prd + drug , data=TotalData)
-summary(LnAUC0INF)
+cat("Type I SS\n")
+LnAUC0INF<- lm(LnAUC0INF ~ seq + subj:seq + prd + drug , data=TotalData)
 show(anova(LnAUC0INF))
 cat("\n")
-cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+cat("Type III SS\n")
+show(drop1(LnAUC0INF, test="F")) 
 cat("\n")
-LnAUC0INF1<- lm(LnAUC0INF ~ seq , data=TotalData)
-show(anova(LnAUC0INF1))
+cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
+print(summary(aov(LnAUC0INF ~ prd*drug + Error(subj) , data=TotalData))) 
 cat("\n")
 cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnAUC0INF)[5,3]),"%\n")
 cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnAUC0INF)[2,3]-anova(LnAUC0INF)[5,3])/2),"%\n")
