@@ -5,7 +5,7 @@ cat("\n")
 file.menu <- c("Input/Edit Data from keyboard",
                "Import Data Files (.CSV)",
                "Load Data Files (.RData)",
-               "Back to NCAmenu",
+               "Back to NCA menu",
                "Quit")
 cat("\n")
 
@@ -20,8 +20,8 @@ cat("*   ->sequence (seq)
 cat("*       Sequence 1:Reference-->Test sequence                               *\n")
 cat("*       Sequence 2:Test-->Reference sequence                               *\n")                                                       
 cat("*   ->period (prd)                                                         *\n")   
-cat("*       Period 1: first treatmetn period                                   *\n")
-cat("*       Period 2: second treatmetn period                                  *\n")                                                       
+cat("*       Period 1: first treatment period                                   *\n")
+cat("*       Period 2: second treatment period                                  *\n")                                                       
 cat("*   ->time                                                                 *\n")
 cat("*   ->concentration (conc)                                                 *\n")
 cat("****************************************************************************\n")
@@ -85,37 +85,37 @@ cat("\n")
 
 else {
   if (pick == 2){
-  cat("\n\n")
-cat("\nEnter subject-period-time-concentration data file name\n")                                            
+cat("\n\n")                                          
 cat("****************************************************************************\n")
 cat("* Data should consist of                                                   *\n")
 cat("*--------------------------------------------------------------------------*\n")
-cat("*   ->subject no.(subj)                                                   *\n")
-cat("*   ->sequence (seq)                                                       *\n")
-cat("*       Sequence 1:Reference-->Test sequence                               *\n")
-cat("*       Sequence 2:Test-->Reference sequence                               *\n")                                                       
-cat("*   ->period (prd)                                                         *\n")   
-cat("*       Period 1: first treatmetn period                                   *\n")
-cat("*       Period 2: second treatmetn period                                  *\n")                                                       
-cat("*   ->time                                                                 *\n")
-cat("*   ->concentration (conc)                                                 *\n")
+cat("* row#1: subj, seq, prd, time, conc                                        *\n")
+cat("* column#1: subject no.(subj)                                              *\n")
+cat("* column#2: sequence (seq)                                                 *\n")
+cat("*          ->Sequence = 1 if Reference-->Test                              *\n")
+cat("*          ->Sequence = 2 if Test-->Reference                              *\n")                                                       
+cat("* column#3: period (prd)                                                   *\n")   
+cat("*          ->Period 1: 1st treatment period                                *\n")
+cat("*          ->Period 2: 2nd treatment period                                *\n")                                                       
+cat("* column#4: time (unit)                                                    *\n")
+cat("* column#5: drug plasma/serum concentration (conc)                         *\n")
 cat("****************************************************************************\n")
-  TotalSingledata.file <-readline()
-  TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
-     cnames<-c("subj", "seq","prd", "time", "conc")
-     TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,sep=",",row.names=NULL,col.names=cnames)
-     TotalSingledata<-edit(TotalSingledata)
-     TotalSingledata<-na.omit(TotalSingledata)
-     cat("\n\n")
-     show(TotalSingledata)   
-
-        return(NCAanalyze(TotalSingledata))
+cat("\n")
+filepath<-getwd()
+cat("R will import your data from the directory of \n")
+cat("",filepath,"\n") 
+    return(NCAcsv())
+   
       }
 
 else {
   if (pick == 3){
     cat("\n\n")
-  cat("\nEnter subject-period-time-concentration data file name\n")
+    filepath<-getwd()
+    cat("R will load your data from the directory of \n")
+    cat("",filepath,"\n")
+    cat("\n")
+    cat("\nEnter Data file name(without file extention of .RData)\n")
      TotalSinglename <-readline()
      TotalSinglename<-paste(TotalSinglename,".RData",sep="")
      load(TotalSinglename)
